# libpythonpro_cursopytools2

Neste curso é ensinado como contribuir com projetos de código abe

Link do curso [Python Pro](https://www.python.pro.br/)

[![Build Status](https://travis-ci.com/MarcosAntonioSoares/libpythonpro_cursopytools2.svg?branch=main)](https://travis-ci.com/MarcosAntonioSoares/libpythonpro_cursopytools2)
[![Updates](https://pyup.io/repos/github/marcosas1990/libpythonpro_cursopytools2/shield.svg)](https://pyup.io/repos/github/marcosas1990/libpythonpro_cursopytools2/)
[![Python 3](https://pyup.io/repos/github/marcosas1990/libpythonpro_cursopytools2/python-3-shield.svg)](https://pyup.io/repos/github/marcosas1990/libpythonpro_cursopytools2/)

Suporta versão 3 de Python

Para instalar:

```console
python3 -m venv .venv
source .venv/bin/activate
pip install -r requirements-dev.txt
```

Para conferir qualidade de código
```console
flake8
```